#! /usr/bin/env python

# This file is part of pdcCreator.  pdcCreator is free software: you can
# redistribute it and/or modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation, version 2.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
# details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc., 51
# Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
# Copyright Andreas Fertig
#------------------------------------------------------------------------------

import sys
import os
import argparse
import shutil
#------------------------------------------------------------------------------


def main():
    parser = argparse.ArgumentParser(description='Create a Projektor Container file.')
    parser.add_argument('-p','--pdf',   help='PDF file',                         required=True)
    parser.add_argument('-n','--notes', help='Notes text file',                  required=True)
    parser.add_argument('-o','--pdc',   help='PDC output file name',             required=True)
    parser.add_argument('-f','--force', help='Force override existing PDC file', required=False, default=False, action='store_true')

    args = parser.parse_args()
    
    # check for validity
    if not os.path.exists( args.pdf ):
        print 'Could not open: %s' %(args.pdf)
        return 1

    if not os.path.exists( args.notes ):
        print 'Could not open: %s' %(args.notes)
        return 1

    pdcDir = args.pdc

    fullFileName, extension = os.path.splitext( args.pdc )
    fileName = os.path.basename(fullFileName)

    if '.pdc' != extension.lower():
        pdcDir = '%s.pdc' %(pdcDir)

    if os.path.exists( pdcDir ):
        if not args.force:
            print 'WARNING: %s already exists' %(pdcDir)
            return 1
    else:
        # create pdc folder
        os.mkdir( pdcDir )

    # move and rename files
    pdfFileName = 'slides.pdf'
    pdfFileAndPath = os.path.join( pdcDir, pdfFileName )
    print pdfFileAndPath
    shutil.copy2( args.pdf, pdfFileAndPath )

    notesFileName = 'notes.xml'
    notesFileAndPath = os.path.join( pdcDir, notesFileName )
    print notesFileAndPath
    shutil.copy2( args.notes, notesFileAndPath )

    return 0
#------------------------------------------------------------------------------

if __name__ == "__main__":
    sys.exit( main() )
#------------------------------------------------------------------------------

